# ZeNBu
Ze(ldovich calculations for) N-B(ody Em)u(lators)

A package to compute all the Zeldovich contributions to the power spectrum of a tracer with quadratic bias, including beyond-one-loop terms.

For further details on the calculations see [Kokron et al](https://arxiv.org/abs/2205.15327) (2022) and [DeRose et al](https://arxiv.org/abs/2210.14239) (2022) for the real and redshift-space calculations, respectively.

Requires [pyFFTW](https://pyfftw.readthedocs.io/en/latest/).

Based on the [velocileptors](https://github.com/sfschen/velocileptors) code.

Can be installed via pip:
```
pip install git+https://github.com/sfschen/ZeNBu
```
